==> 1.2025.316.6.tar.gz: OBJECTS/gen/ui/webui/resources/tsc/cr_components/composebox/recent_tab_chip.js <==
// Copyright 2025 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
import '//resources/cr_elements/cr_button/cr_button.js';
import './composebox_tab_favicon.js';
import { I18nMixinLit } from '//resources/cr_elements/i18n_mixin_lit.js';
import { assert } from '//resources/js/assert.js';
import { CrLitElement } from '//resources/lit/v3_0/lit.rollup.js';
import { getCss } from './recent_tab_chip.css.js';
import { getHtml } from './recent_tab_chip.html.js';
const RecentTabChipBase = I18nMixinLit(CrLitElement);
export class RecentTabChipElement extends RecentTabChipBase {
    static get is() {
        return 'composebox-recent-tab-chip';
    }
    static get styles() {
        return getCss();
    }
    render() {
        return getHtml.bind(this)();
    }
    static get properties() {
        return {
            // =========================================================================
            // Public properties
            // =========================================================================
            inputsDisabled: { type: Boolean },
            recentTab: { type: Object },
        };
    }
    #inputsDisabled_accessor_storage = false;
    get inputsDisabled() { return this.#inputsDisabled_accessor_storage; }
    set inputsDisabled(value) { this.#inputsDisabled_accessor_storage = value; }
    #recentTab_accessor_storage = undefined;
    get recentTab() { return this.#recentTab_accessor_storage; }
    set recentTab(value) { this.#recentTab_accessor_storage = value; }
    addTabContext_(e) {
        e.stopPropagation();
        assert(this.recentTab);
        assert(!this.inputsDisabled);
        this.fire('add-tab-context', {
            id: this.recentTab.tabId,
            title: this.recentTab.title,
            url: this.recentTab.url,
        });
    }
}
customElements.define(RecentTabChipElement.is, RecentTabChipElement);

==> 1.2025.323.6.tar.gz: OBJECTS/gen/ui/webui/resources/tsc/cr_components/composebox/recent_tab_chip.js <==
// Copyright 2025 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
import '//resources/cr_elements/cr_button/cr_button.js';
import './composebox_tab_favicon.js';
import { I18nMixinLit } from '//resources/cr_elements/i18n_mixin_lit.js';
import { assert } from '//resources/js/assert.js';
import { loadTimeData } from '//resources/js/load_time_data.js';
import { CrLitElement } from '//resources/lit/v3_0/lit.rollup.js';
import { getCss } from './recent_tab_chip.css.js';
import { getHtml } from './recent_tab_chip.html.js';
const RecentTabChipBase = I18nMixinLit(CrLitElement);
export class RecentTabChipElement extends RecentTabChipBase {
    static get is() {
        return 'composebox-recent-tab-chip';
    }
    static get styles() {
        return getCss();
    }
    render() {
        return getHtml.bind(this)();
    }
    static get properties() {
        return {
            // =========================================================================
            // Public properties
            // =========================================================================
            recentTab: { type: Object },
        };
    }
    #recentTab_accessor_storage = undefined;
    get recentTab() { return this.#recentTab_accessor_storage; }
    set recentTab(value) { this.#recentTab_accessor_storage = value; }
    delayTabUploads_ = loadTimeData.getBoolean('addTabUploadDelayOnRecentTabChipClick');
    addTabContext_(e) {
        e.stopPropagation();
        assert(this.recentTab);
        this.fire('add-tab-context', {
            id: this.recentTab.tabId,
            title: this.recentTab.title,
            url: this.recentTab.url,
            delayUpload: this.delayTabUploads_,
        });
    }
}
customElements.define(RecentTabChipElement.is, RecentTabChipElement);
